==> sui-login-password-reset-1.16.0.tgz: package/lib/components/Content/PasswordReset.js <==
import { BASE_CLASS, STAGE_PASSWORD_RESET_START } from '../../config.js';
import useGetCurrentToken from '../../hooks/useGetCurrentToken.js';
import UserAcquisitionText from '../Info/UserAcquisitionText.js';
import PasswordChangeForm from '../Form/PasswordChangeForm.js';
import PasswordResetForm from '../Form/PasswordResetForm.js';
import StageInfo from './StageInfo.js';
import Form from './Form.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var PasswordReset = function PasswordReset() {
  var _useGetCurrentToken = useGetCurrentToken(),
    getCurrentToken = _useGetCurrentToken.getCurrentToken;
  var _getCurrentToken = getCurrentToken(),
    stage = _getCurrentToken.stage;
  var isInitialStep = stage === STAGE_PASSWORD_RESET_START;
  return /*#__PURE__*/_jsxs("div", {
    className: BASE_CLASS,
    children: [/*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-item",
      children: /*#__PURE__*/_jsx(StageInfo, {})
    }), /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-item",
      children: /*#__PURE__*/_jsx(Form, {
        children: isInitialStep ? /*#__PURE__*/_jsxs(_Fragment, {
          children: [/*#__PURE__*/_jsx(PasswordResetForm, {}), /*#__PURE__*/_jsx(UserAcquisitionText, {})]
        }) : /*#__PURE__*/_jsx(_Fragment, {
          children: /*#__PURE__*/_jsx(PasswordChangeForm, {})
        })
      })
    }), /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-item " + BASE_CLASS + "-itemFalse"
    })]
  });
};
PasswordReset.displayName = 'PasswordReset';
export default PasswordReset;

==> sui-login-password-reset-1.32.0.tgz: package/lib/components/Content/PasswordReset.js <==
import PropTypes from 'prop-types';
import { BASE_CLASS, STAGE_PASSWORD_RESET_START } from '../../config.js';
import useGetCurrentToken from '../../hooks/useGetCurrentToken.js';
import PasswordChangeForm from '../Form/PasswordChangeForm.js';
import PasswordResetForm from '../Form/PasswordResetForm.js';
import UserAcquisitionText from '../Info/UserAcquisitionText.js';
import Form from './Form.js';
import StageInfo from './StageInfo.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var PasswordReset = function PasswordReset(_ref) {
  var icons = _ref.icons;
  var _useGetCurrentToken = useGetCurrentToken(),
    getCurrentToken = _useGetCurrentToken.getCurrentToken;
  var _getCurrentToken = getCurrentToken(),
    stage = _getCurrentToken.stage;
  var isInitialStep = stage === STAGE_PASSWORD_RESET_START;
  return /*#__PURE__*/_jsxs("div", {
    className: BASE_CLASS,
    children: [/*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-item",
      children: /*#__PURE__*/_jsx(StageInfo, {})
    }), /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-item",
      children: /*#__PURE__*/_jsx(Form, {
        icons: icons,
        children: isInitialStep ? /*#__PURE__*/_jsxs(_Fragment, {
          children: [/*#__PURE__*/_jsx(PasswordResetForm, {
            icons: icons
          }), /*#__PURE__*/_jsx(UserAcquisitionText, {})]
        }) : /*#__PURE__*/_jsx(_Fragment, {
          children: /*#__PURE__*/_jsx(PasswordChangeForm, {
            icons: icons
          })
        })
      })
    }), /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-item " + BASE_CLASS + "-itemFalse"
    })]
  });
};
PasswordReset.displayName = 'PasswordReset';
export default PasswordReset;
